@@ -1,4 +1,4 @@
-.onLoad <- function(lib, pkg) {
+.onAttach <- function(lib, pkg) {
     where <- match(paste("package:", pkg, sep = ""), search())
     ver <- read.dcf(file.path(lib, pkg, "DESCRIPTION"), "Version")
     ver <- as.character(ver)
